@@ -1,35 +1,31 @@
 # 内核工具                      backend
 from files3.basic_files import pyfile_basic_files   # 最基本的Files     basic Files
 from files3.files import pyfile_files               # 通用Files         normal Files
-from files3.ex_files import pyfile_ex_files         # 高级功能Files     ex functional Files
 
 # 加壳工具(主要用于用户交互)                    shell tool(user frendly API)
-from files3.pyfile_shell import pyfile_shell_basic, pyfile_shell, pyfile_shell_ex
+from files3.pyfile_shell import pyfile_shell_basic, pyfile_shell
 
-afiles = pyfile_shell_ex     # advanced files    # 主要用户调用的files-shell(ex)类
-bfiles = pyfile_shell        # basic files      # 基础功能files-shell(std)类
-cfiles = pyfile_shell_basic  # core files       # 内核files-shell(base)类
+files  = pyfile_shell        # std   files       # 标准功能files-shell(std)类
+bfiles = pyfile_shell_basic  # basic files       # 内核files-shell(base)类
 
 """
-afiles推荐用于常规项目的中小批量数据保存
-bfiles不能进行文件加密和解密
-cfiles只能进行最基本的单个增删改查(但是原理最简单，封装程度最浅，利于效率)
+files 带有魔法方法
+bfiles只能进行最基本的单个增删改查(但是原理最简单，封装程度最浅，利于效率)
 
-afiles is recommended for saving small and medium batch data of regular projects
-bfiles cannot encrypt and decrypt files
-cfiles can only perform the most basic single addition, deletion, modification and query (but the principle is the simplest and the encapsulation degree is the shallowest, which is conducive to efficiency)
+files with magic methods
+bfiles can only perform the most basic single addition, deletion, modification and query (but the principle is the simplest and the encapsulation degree is the shallowest, which is conducive to efficiency)
 """
 
 # 默认值                          default
-files       =   afiles    # 作者常用        (the way author like)
-Files       =   afiles
-PyFile      =   afiles
-PyFiles     =   afiles
-pyfile      =   afiles
-pyfiles     =   afiles
+files       =   files    # 作者常用        (the way author like)
+Files       =   files
+PyFile      =   files
+PyFiles     =   files
+pyfile      =   files
+pyfiles     =   files
 
 
-__version__ = "0.2.2"
+__version__ = "0.3.2"
 __author__ = "Eagle'sBaby"
 __doc__ ="""
 
@@ -145,9 +141,7 @@ en: (machine translate:)
 """
 
 if __name__ == '__main__':
+    import numpy as np
     f = files("test")
-    f.abcd = 123
-    f['b'] = 456
-    f['c', 'd'] = 789
-    f.encrypt('a')
-    print(f[...])
+    #f.a = np.array([123, 456])
+    print(f.a, type(f.a))
