@@ -5,17 +5,16 @@ from files3.InfoPackage import *
 from files3.PfBool import *
 from files3.basic_files import pyfile_basic_files
 from files3.files import pyfile_files
-from files3.ex_files import pyfile_ex_files
 
 function = type(lambda: ...)
 
 class pyfile_shell_base(object):
     info: InfoPackage = None
-    backend: pyfile_ex_files = pyfile_ex_files()
+    backend: pyfile_files = pyfile_files()
     _ready = False
 
-    def __init__(self, path, type=".inst", aes_type=".aes", backend_type=pyfile_ex_files):
-        self.info = InfoPackage(path, type, aes_type)
+    def __init__(self, path, type=".inst", backend_type=pyfile_files):
+        self.info = InfoPackage(path, type)
         self.backend = backend_type()
         assert hasattr(self.backend, "_pflevel"), "backend must be one of pyfile.?files. not " + str(self.backend)
 
@@ -164,8 +163,8 @@ class pyfile_shell_magic(object):  # assert _pflevel >= 1
 
 
 class pyfile_shell_basic(pyfile_shell_base, pyfile_shell_basic_magic):
-    def __init__(self, path="", type=".inst", aes_type=".aes"):
-        pyfile_shell_base.__init__(self, path, type, aes_type, pyfile_basic_files)
+    def __init__(self, path="", type=".inst"):
+        pyfile_shell_base.__init__(self, path, type, pyfile_basic_files)
 
     def has(self, key:str) -> PfBool:
         """
@@ -224,8 +223,8 @@ class pyfile_shell_basic(pyfile_shell_base, pyfile_shell_basic_magic):
 
 
 class pyfile_shell(pyfile_shell_base, pyfile_shell_magic):
-    def __init__(self, path="", type=".inst", aes_type=".aes"):
-        pyfile_shell_base.__init__(self, path, type, aes_type, pyfile_files)
+    def __init__(self, path="", type=".inst"):
+        pyfile_shell_base.__init__(self, path, type, pyfile_files)
 
     def has(self, key:str) -> PfBool:
         """
@@ -280,90 +279,6 @@ class pyfile_shell(pyfile_shell_base, pyfile_shell_magic):
         return self.backend.list(self.info)
 
 
-
-class pyfile_shell_ex(pyfile_shell_base, pyfile_shell_magic):
-    def __init__(self, path="", type=".inst", aes_type=".aes"):
-        pyfile_shell_base.__init__(self, path, type, aes_type, pyfile_ex_files)
-
-    def has(self, key:str) -> PfBool:
-        """
-        增删改查之番外-事先确认。成功返回PfTrue，如果目标文件不存在，则返回PfFalse
-        Has a pyfile file exists. Returns True successfully, or False if the target file doesnot exists
-
-        :param info:     InfoPackage inst
-        :param key:      文件名称，类似数据库的主键，不能重复
-                         File name. It is similar to the primary key of a database and cannot be duplicated
-        """
-        return self.backend.has(self.info, key)
-
-    def set(self, key: str, pyobject: object) -> PfBool:
-        """
-        存储python对象到目标文件夹下。成功返回PfTrue，如果目标文件被锁定或占用，则返回PfFalse
-        Storing Python objects to pyfile under specific path in InfoPackage. Returns True successfully. If the target file is locked or occupied, returns False
-
-        :param key:      文件名称，类似数据库的主键，不能重复
-                         File name. It is similar to the primary key of a database and cannot be duplicated
-        :param pyobject: python对象   python object
-        """
-        return self.backend.set(self.info, key, pyobject)
-
-    def get(self, key: str) -> PfBool:
-        """
-        从目标文件夹下读取pyfile到python对象。成功返回读取到的pyobject，如果目标文件不存在，则返回PfFalse
-        Read the pyfile under specific path in InfoPackage from the target folder to the python object. The read pyobject is returned successfully. If the target file does not exist, false is returned
-
-        如果目标是加密文件，pyfile会尝试进行解密。成功解密则返回解密后的数据，未成功则返回该加密文件的加密信息。
-        If the target is an encrypted file, pyfile attempts to decrypt it. If the decryption is successful, the decrypted data will be returned; if not, the encrypted information of the encrypted file will be returned.
-
-        :param key:      文件名称，类似数据库的主键，不能重复
-                         File name. It is similar to the primary key of a database and cannot be duplicated
-        """
-        return self.backend.get(self.info, key)
-
-    def delete(self, key: str) -> PfBool:
-        """
-        增删改查之'删'。成功或目标文件不存在则返回PfTrue，如果目标文件存在而无法删除，则返回PfFalse
-        Delete pyfile file. Returns True if the target file is successful or does not exist. Returns False if the target file exists and cannot be deleted
-
-        :param key:      文件名称，类似数据库的主键，不能重复
-                         File name. It is similar to the primary key of a database and cannot be duplicated
-        """
-        return self.backend.delete(self.info, key)
-
-    def list(self, type=False) -> list:
-        """
-        列举目标文件夹下所有info.type类型的文件的key。返回一个列表结果
-        List all info of keys (In the target folder The key of a file of type). Returns a list result
-
-        :param type:     whether with suffix or not
-        """
-        return self.backend.list(self.info)
-
-    def encrypt(self, key:str, local=False)->PfBool:
-        """
-        对名称为key的pyfile文件进行加密, 成功返回PfTrue，失败返回PfFalse。
-        Encrypt the pyfile file named key.Returns True for success and False for failure.
-
-        :param key:      文件名称，类似数据库的主键，不能重复
-                     File name. It is similar to the primary key of a database and cannot be duplicated
-        :param local:    是否加入本地信息, 加入本地信息后不同计算机将无法对文件进行解密
-                          Whether to add local information. After adding local information, different computers will not be able to decrypt the file
-        """
-        return self.backend.encrypt(self.info, key, local)
-
-    def decrypt(self, key:str, recursion=False)->object:
-        """
-        对名称为key的pyfile文件进行解密, 成功返回object，失败返回PfFalse。
-        Decrypt the pyfile file named key.Returns True for success and False for failure.
-
-        :param key:      文件名称，类似数据库的主键，不能重复
-                     File name. It is similar to the primary key of a database and cannot be duplicated
-        :param recursion:   是否以递归的方式解密， 用于嵌套加密的解密。
-                        Whether to decrypt recursively. Decryption for nested encryption.
-        """
-        return self.backend.decrypt(self.info, key, recursion)
-
-
 if __name__ == '__main__':
     import time
     from pyfilehash import info, hash32
